# Generated by Django 1.11.20 on 2019-02-18 20:17
from django.db import migrations
from django.db.models import F, Func, Value
from django.db.models.functions import Concat


def forwards_func(apps, schema_editor):
    icon = apps.get_model('djangocms_icon', 'Icon')

    icon.objects.filter(icon__startswith='el-icon-').update(icon=Concat(Value('el '), 'icon'))
    icon.objects.filter(icon__startswith='flag-icon-').update(icon=Concat(Value('flag-icon '), 'icon'))
    icon.objects.filter(icon__startswith='fa-').update(icon=Concat(Value('fa '), 'icon'))
    icon.objects.filter(icon__startswith='glyphicon-').update(icon=Concat(Value('glyphicon '), 'icon'))
    icon.objects.filter(icon__startswith='ion-').update(icon=Concat(Value('ion '), 'icon'))
    icon.objects.filter(icon__startswith='map-icon-').update(icon=Concat(Value('map-icon '), 'icon'))
    icon.objects.filter(icon__startswith='zmdi-').update(icon=Concat(Value('zmdi '), 'icon'))
    icon.objects.filter(icon__startswith='wi-').update(icon=Concat(Value('wi '), 'icon'))


def reverse_func(apps, schema_editor):  # pragma: no cover
    icon = apps.get_model('djangocms_icon', 'Icon')

    icon.objects.filter(icon__startswith='el ').update(icon=Func(F('icon'), Value('el '), Value(''), function='replace',))
    icon.objects.filter(icon__startswith='flag-icon ').update(icon=Func(F('icon'), Value('flag-icon '), Value(''), function='replace',))
    icon.objects.filter(icon__startswith='fa ').update(icon=Func(F('icon'), Value('fa '), Value(''), function='replace',))
    icon.objects.filter(icon__startswith='glyphicon ').update(icon=Func(F('icon'), Value('glyphicon '), Value(''), function='replace',))
    icon.objects.filter(icon__startswith='map-icon ').update(icon=Func(F('icon'), Value('map-icon '), Value(''), function='replace',))
    icon.objects.filter(icon__startswith='zmdi ').update(icon=Func(F('icon'), Value('zmdi '), Value(''), function='replace',))
    icon.objects.filter(icon__startswith='wi ').update(icon=Func(F('icon'), Value('wi '), Value(''), function='replace',))


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_icon', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(forwards_func, reverse_func),
    ]



from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from cms.models import CMSPlugin

from djangocms_attributes_field.fields import AttributesField

from .fields import Icon


# Add additional choices through the ``settings.py``.
def get_templates():
    choices = [
        ('default', _('Default')),
    ]
    choices += getattr(
        settings,
        'DJANGOCMS_ICON_TEMPLATES',
        [],
    )
    return choices


class AbstractIcon(CMSPlugin):
    icon = Icon()

    template = models.CharField(
        verbose_name=_('Template'),
        choices=get_templates(),
        default=get_templates()[0][0],
        max_length=255,
    )
    label = models.CharField(
        verbose_name=_('Label'),
        blank=True,
        max_length=255,
    )
    attributes = AttributesField(
        verbose_name=_('Attributes'),
        blank=True,
    )

    class Meta:
        abstract = True

    def __str__(self):
        return str(self.pk)

    def get_short_description(self):
        return self.label or ''


class Icon(AbstractIcon):
    class Meta:
        abstract = False



from django.conf import settings
from django.test import TestCase

from djangocms_icon.fields import get_iconsets


class IconFieldTestCase(TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_iconsets(self):
        self.assertEqual(
            get_iconsets(),
            (
                ('fontawesome5regular', 'far', 'Font Awesome 5 Regular', 'lastest'),
                ('fontawesome5solid', 'fas', 'Font Awesome 5 Solid', 'lastest'),
                ('fontawesome5brands', 'fab', 'Font Awesome 5 Brands', 'lastest'),
            ),
        )
        settings.DJANGOCMS_ICON_SETS = []
        self.assertEqual(get_iconsets(), ())
        settings.DJANGOCMS_ICON_SETS = [('glyphicon', 'glyphicon', 'Glyphicons')]
        self.assertEqual(get_iconsets(), (('glyphicon', 'glyphicon', 'Glyphicons', 'lastest'),))
        # will append "lastest" for compatibility reasons
        settings.DJANGOCMS_ICON_SETS = [
            ('fontawesome5regular', 'far', 'Font Awesome 5 Regular'),
            ('fontawesome5solid', 'fas', 'Font Awesome 5 Solid'),
            ('fontawesome5brands', 'fab', 'Font Awesome 5 Brands'),
        ]
        self.assertEqual(
            get_iconsets(),
            (
                ('fontawesome5regular', 'far', 'Font Awesome 5 Regular', 'lastest'),
                ('fontawesome5solid', 'fas', 'Font Awesome 5 Solid', 'lastest'),
                ('fontawesome5brands', 'fab', 'Font Awesome 5 Brands', 'lastest'),
            ),
        )



import os
import warnings

from django.conf import settings

from cms.api import add_plugin, create_page
from cms.test_utils.testcases import CMSTestCase

from djangocms_icon.cms_plugins import IconPlugin


class IconPluginsTestCase(CMSTestCase):

    def setUp(self):
        self.language = "en"
        self.home = create_page(
            title="home",
            template="page.html",
            language=self.language,
        )
        self.home.publish(self.language)
        self.page = create_page(
            title="content",
            template="page.html",
            language=self.language,
        )
        self.page.publish(self.language)
        self.placeholder = self.page.placeholders.get(slot="content")
        self.superuser = self.get_superuser()

    def tearDown(self):
        self.page.delete()
        self.home.delete()
        self.superuser.delete()

    def test_icon_plugin(self):
        plugin = add_plugin(
            placeholder=self.placeholder,
            plugin_type=IconPlugin.__name__,
            language=self.language,
        )
        plugin.full_clean()  # should not raise an error
        self.assertEqual(plugin.plugin_type, "IconPlugin")

    def test_plugin_structure(self):
        request_url = self.page.get_absolute_url(self.language) + "?toolbar_off=true"

        plugin = add_plugin(
            placeholder=self.placeholder,
            plugin_type=IconPlugin.__name__,
            language=self.language,
            icon="fa-icon",
        )
        self.page.publish(self.language)
        self.assertEqual(plugin.get_plugin_class_instance().name, "Icon")

        with self.login_user_context(self.superuser):
            response = self.client.get(request_url)

        self.assertContains(response, '<i class="fa-icon" aria-hidden="true"></i>')

    def test_full_plugin_render(self):
        request_url = self.get_add_plugin_uri(
            placeholder=self.placeholder,
            plugin_type=IconPlugin.__name__,
            language=self.language,
        )
        data = {
            "icon": "fas fa-address-book",
            "template": "default"
        }

        with self.login_user_context(self.superuser), warnings.catch_warnings():
            # hide the "DontUsePageAttributeWarning" warning when using
            # `get_add_plugin_uri` to get cleaner test results
            warnings.simplefilter("ignore")
            response = self.client.get(request_url)
            submission = self.client.post(request_url, data)

        self.assertEquals(response.status_code, 200)
        self.assertContains(response, '<div class="djangocms-icon"')
        # plugin succeeded and the change page view is shown
        self.assertEquals(submission.status_code, 200)
        self.assertContains(submission, "Change a page")
        self.assertNotIn(b"Please correct the errors below.", submission.content)

    def test_custom_plugin_render(self):
        request_url = self.get_add_plugin_uri(
            placeholder=self.placeholder,
            plugin_type=IconPlugin.__name__,
            language=self.language,
        )

        settings.DJANGOCMS_ICON_SETS = [
            ('fontawesome4', 'fa', 'Font Awesome 4'),
        ]
        data = {
            "icon": "fa fa-address-book",
            "template": "default"
        }

        with self.login_user_context(self.superuser), warnings.catch_warnings():
            # hide the "DontUsePageAttributeWarning" warning when using
            # `get_add_plugin_uri` to get cleaner test results
            warnings.simplefilter("ignore")
            response = self.client.get(request_url)
            submission = self.client.post(request_url, data)

        self.assertEquals(response.status_code, 200)
        self.assertContains(response, '<div class="djangocms-icon"')
        # plugin succeeded and the change page view is shown
        self.assertEquals(submission.status_code, 200)
        self.assertContains(submission, "Change a page")
        self.assertNotIn(b"Please correct the errors below.", submission.content)

    def test_json_plugin_render(self):
        request_url = self.get_add_plugin_uri(
            placeholder=self.placeholder,
            plugin_type=IconPlugin.__name__,
            language=self.language,
        )
        iconset = os.path.join(
            os.path.dirname(__file__),
            'sample_web.json',
        )

        with open(iconset) as fh:
            ICONSET = fh.read()

        settings.DJANGOCMS_ICON_SETS = [
            ('fontawesome4', 'fa', 'Font Awesome 4'),
            (ICONSET, 'custom_icon', 'Custom web font'),
        ]
        data = {
            "icon": "custom_icon icon-icon1",
            "template": "default"
        }

        with self.login_user_context(self.superuser), warnings.catch_warnings():
            # hide the "DontUsePageAttributeWarning" warning when using
            # `get_add_plugin_uri` to get cleaner test results
            warnings.simplefilter("ignore")
            response = self.client.get(request_url)
            submission = self.client.post(request_url, data)

        self.assertEquals(response.status_code, 200)
        self.assertContains(response, 'Font Awesome 4')
        self.assertContains(response, 'Custom web font')
        self.assertContains(response, '<div class="djangocms-icon"')
        # plugin succeeded and the change page view is shown
        self.assertEquals(submission.status_code, 200)
        self.assertContains(submission, "Change a page")
        self.assertNotIn(b"Please correct the errors below.", submission.content)

    def test_svg_plugin_render(self):
        request_url = self.get_add_plugin_uri(
            placeholder=self.placeholder,
            plugin_type=IconPlugin.__name__,
            language=self.language,
        )
        iconset = os.path.join(
            os.path.dirname(__file__),
            'sample_svg.json',
        )

        with open(iconset) as fh:
            ICONSET = fh.read()

        settings.DJANGOCMS_ICON_SETS = [
            ('fontawesome4', 'fa', 'Font Awesome 4'),
            (ICONSET, 'svg_icon', 'Custom svg font'),
        ]
        data = {
            "icon": "svg_icon icon-icon2",
            "template": "default"
        }

        with self.login_user_context(self.superuser), warnings.catch_warnings():
            # hide the "DontUsePageAttributeWarning" warning when using
            # `get_add_plugin_uri` to get cleaner test results
            warnings.simplefilter("ignore")
            response = self.client.get(request_url)
            submission = self.client.post(request_url, data)

        self.assertEquals(response.status_code, 200)
        self.assertContains(response, 'Font Awesome 4')
        self.assertContains(response, 'Custom svg font')
        self.assertContains(response, '<div class="djangocms-icon"')
        # plugin succeeded and the change page view is shown
        self.assertEquals(submission.status_code, 200)
        self.assertContains(submission, "Change a page")
        self.assertNotIn(b"Please correct the errors below.", submission.content)



from django import forms

from .fields import IconField
from .models import Icon


class IconForm(forms.ModelForm):
    icon = IconField(required=True)

    class Meta:
        model = Icon
        fields = ('label', 'icon', 'template', 'attributes',)



from django.conf import settings
from django.db import models
from django.forms import fields, widgets
from django.template.loader import render_to_string
from django.utils.translation import gettext


def get_iconsets():
    iconsets = getattr(settings, 'DJANGOCMS_ICON_SETS', (
        ('fontawesome5regular', 'far', 'Font Awesome 5 Regular', 'lastest'),
        ('fontawesome5solid', 'fas', 'Font Awesome 5 Solid', 'lastest'),
        ('fontawesome5brands', 'fab', 'Font Awesome 5 Brands', 'lastest'),
    ))

    current_iconsets = []
    for iconset in iconsets:
        if len(iconset) == 3:
            iconset = iconset + ('lastest',)
        current_iconsets.append(iconset)

    return tuple(current_iconsets)


class IconFieldWidget(widgets.TextInput):
    class Media:
        css = {
            'all': (
                'djangocms_icon/css/djangocms-icon.css',
            )
        }
        js = (
            'djangocms_icon/js/dist/bundle.icon.min.js',
        )

    def render(self, name, value, attrs=None, **kwargs):  # pragma: no cover
        if value is None:
            value = ''

        iconsets = get_iconsets()
        active_iconset = iconsets[0]

        if value:
            segments = value.split(None, 1)
            selected_iconset = None

            # check is in place for older iconset configurations where
            # this would otherwise throw a "list range out of index" error
            try:
                value = segments[1]

                for iconset in iconsets:
                    if iconset[1] == segments[0]:
                        selected_iconset = iconset
                        break
            except IndexError:
                pass

            active_iconset = active_iconset if selected_iconset is None else selected_iconset

        rendered = render_to_string(
            'admin/djangocms_icon/widgets/icon.html',
            {
                'value': value,
                'name': name,
                'iconset': active_iconset[0],
                'version': active_iconset[3],
                'prefix': active_iconset[1],
                'is_required': self.is_required,
                'iconsets': iconsets,
            },
        )

        return rendered


class IconField(fields.CharField):
    widget = IconFieldWidget
    DEFAULT = ''

    def __init__(self, *args, **kwargs):
        if 'initial' not in kwargs:
            kwargs['initial'] = self.DEFAULT
        kwargs.pop('coerce', None)
        kwargs.pop('max_length', None)
        kwargs.pop('widget', None)
        kwargs['widget'] = self.widget
        super().__init__(*args, **kwargs)


class Icon(models.CharField):
    default_field_class = IconField
    south_field_class = 'models.fields.CharField'

    def __init__(self, *args, **kwargs):
        if 'verbose_name' not in kwargs:
            kwargs['verbose_name'] = gettext('Icon')
        if 'max_length' not in kwargs:
            kwargs['max_length'] = 255
        if 'blank' not in kwargs:
            kwargs['blank'] = True
        if 'default' not in kwargs:
            kwargs['default'] = self.default_field_class.DEFAULT
        super().__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            'form_class': self.default_field_class,
        }
        defaults.update(kwargs)
        return super().formfield(**defaults)



import django.db.models.deletion
from django.db import migrations, models

import djangocms_attributes_field.fields

import djangocms_icon.fields
from djangocms_icon.models import get_templates


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='Icon',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='cms.CMSPlugin', related_name='djangocms_icon_icon', primary_key=True, serialize=False, parent_link=True, auto_created=True)),
                ('icon', djangocms_icon.fields.Icon(max_length=255, default='', verbose_name='Icon', blank=True)),
                ('template', models.CharField(max_length=255, default=get_templates()[0][0], verbose_name='Template', choices=get_templates())),
                ('label', models.CharField(max_length=255, verbose_name='Label', blank=True)),
                ('attributes', djangocms_attributes_field.fields.AttributesField(default=dict, verbose_name='Attributes', blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



from django.utils.translation import gettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .forms import IconForm
from .models import Icon


class IconPlugin(CMSPluginBase):
    model = Icon
    form = IconForm
    name = _('Icon')
    allow_children = True
    text_enabled = True

    fieldsets = [
        (None, {
            'fields': (
                ('icon', 'label'),
            )
        }),
        (_('Advanced settings'), {
            'classes': ('collapse',),
            'fields': (
                'template',
                'attributes',
            )
        }),
    ]

    def get_render_template(self, context, instance, placeholder):
        return 'djangocms_icon/{}/icon.html'.format(instance.template)


plugin_pool.register_plugin(IconPlugin)



#!/usr/bin/env python
from setuptools import find_packages, setup

from djangocms_icon import __version__


REQUIREMENTS = [
    'django-cms>=3.7',
    'djangocms-attributes-field>=1',
]


CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Framework :: Django',
    'Framework :: Django :: 2.2',
    'Framework :: Django :: 3.0',
    'Framework :: Django :: 3.1',
    'Framework :: Django CMS',
    'Framework :: Django CMS :: 3.7',
    'Framework :: Django CMS :: 3.8',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries',
]


setup(
    name='djangocms-icon',
    version=__version__,
    author='Divio AG',
    author_email='info@divio.com',
    url='https://github.com/divio/djangocms-icon',
    license='BSD-3-Clause',
    description='Adds icon plugin to django CMS.',
    long_description=open('README.rst').read(),
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=REQUIREMENTS,
    classifiers=CLASSIFIERS,
    test_suite='tests.settings.run',
)



from django.conf import settings
from django.test import TestCase

from djangocms_icon.models import Icon, get_templates


class IconModelTestCase(TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_settings(self):
        self.assertEqual(get_templates(), [("default", "Default")])
        settings.DJANGOCMS_ICON_TEMPLATES = [("feature", "Feature")]
        self.assertEqual(get_templates(), [("default", "Default"), ("feature", "Feature")])

    def test_icon_instance(self):
        Icon.objects.create(
            icon="fa-heart",
            template="default",
            label="some label",
            attributes="{'data-type', 'icon'}",
        )
        instance = Icon.objects.all()
        self.assertEqual(instance.count(), 1)
        instance = Icon.objects.first()
        self.assertEqual(instance.icon, "fa-heart")
        self.assertEqual(instance.template, "default")
        self.assertEqual(instance.label, "some label")
        self.assertEqual(instance.attributes, "{'data-type', 'icon'}")
        # test strings
        self.assertEqual(str(instance), "1")
        self.assertEqual(instance.get_short_description(), "some label")
        instance.label = None
        self.assertEqual(instance.get_short_description(), "")
